/***********************************************************
 * $Id$
 *
 * FancyLibs qmi wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQMIENUMS_H_
#define FANCYQMIENUMS_H_

#include <fancyqmi.h>
#include <iosfwd>

namespace Fancy {
namespace QMI {

// https://www.freedesktop.org/software/libqmi/libqmi-glib/1.8.0/libqmi-glib-DMS-enumerations-and-flags.html#QmiDmsOperatingMode-enum
enum OperatingMode {
    OperatingModeOnline                = 0,
	OperatingModeLowPower              = 1,
	OperatingModeFactoryTest           = 2,
	OperatingModeOffline               = 3,
	OperatingModeReset                 = 4,
	OperatingModeShuttingDown          = 5,
	OperatingModePersistentLowPower    = 6,
	OperatingModeOnlyLowPower          = 7,
	OperatingModeUnknown               = 0xFF
};

const char* FANCYQMI_API formatOperatingMode(OperatingMode om);

// https://www.freedesktop.org/software/libqmi/libqmi-glib/1.22.0/QmiDevice.html#QmiDeviceOpenFlags
// /usr/include/libqmi-glib/qmi-device.h
enum DeviceOpenFlag {

	DeviceOpenFlagVersionInfo    = 1 << 0,
	DeviceOpenFlagSync           = 1 << 1,
	DeviceOpenFlagNet_802_3      = 1 << 2,
	DeviceOpenFlagNetRawIP       = 1 << 3,
	DeviceOpenFlagNetQoSHeader   = 1 << 4,
	DeviceOpenFlagNetNoQoSHeader = 1 << 5,
	DeviceOpenFlagProxy          = 1 << 6,
	DeviceOpenFlagMBIM           = 1 << 7,
	DeviceOpenFlagAuto              = 1 << 8,
	DeviceOpenFlagExpectIndications = 1 << 9
};

std::string FANCYQMI_API formatDeviceOpenFlagMask(int deviceOpenFlagMask);

enum RadioInterface {
    RadioInterfaceUnknown     = -1,
    RadioInterfaceNone        = 0x00,
    RadioInterfaceCDMA1X      = 0x01,
    RadioInterfaceCDMA1XEVDO  = 0x02,
    RadioInterfaceAMPS        = 0x03,
    RadioInterfaceGSM         = 0x04,
    RadioInterfaceUMTS        = 0x05,
    RadioInterfaceLTE         = 0x08,
    RadioInterfaceTD_SCDMA    = 0x09
};

const char* FANCYQMI_API formatRadioInterface(RadioInterface ri);

/**
 * RadioTechnologyPreference and QmiNasClient::setNetworkPreference()
 * is deprecated, use RatModePreference mask and
 * QmiNasClient::setRatModePreferenceMask() instead
 */
enum RadioTechnologyPreference {
	RadioTechnologyPreferenceAUTO          = 0,
	RadioTechnologyPreference3GPP2         = 1 << 0,
	RadioTechnologyPreference3GPP          = 1 << 1,
	RadioTechnologyPreferenceAMPS_OR_GSM   = 1 << 2,
	RadioTechnologyPreferenceCDMA_OR_WCDMA = 1 << 3,
	RadioTechnologyPreferenceHDR           = 1 << 4,
	RadioTechnologyPreferenceLTE           = 1 << 5
};

const char * FANCYQMI_API formatRadioTechnologyPreference(RadioTechnologyPreference rtp);

enum PreferenceDuration {
	PreferenceDurationPERMANENT           = 0x00,
	PreferenceDurationPOWER_CYCLE         = 0x01,
	PreferenceDurationONE_CALL            = 0x02,
	PreferenceDurationONE_CALL_OR_TIME    = 0x03,
	PreferenceDurationINTERNAL_ONE_CALL_1 = 0x04,
	PreferenceDurationINTERNAL_ONE_CALL_2 = 0x05,
	PreferenceDurationINTERNAL_ONE_CALL_3 = 0x06
};

const char * FANCYQMI_API formatPreferenceDuration(PreferenceDuration pd);

enum RatModePreference {
	RatModePreference_CDMA_1X     = 1 << 0,
	RatModePreference_CDMA_1XEVDO = 1 << 1,
	RatModePreference_GSM         = 1 << 2,
	RatModePreference_UMTS        = 1 << 3,
	RatModePreference_LTE         = 1 << 4,
	RatModePreference_TD_SCDMA    = 1 << 5
};

std::string FANCYQMI_API formatRatModePreferenceMask(int ratModePreferenceMask);

enum NetworkServiceDomain {
	NetworkServiceDomain_NONE    = 0x00,
	/**
	 * circuit switched
	 */
	NetworkServiceDomain_CS      = 0x01,
	/**
	 * packet switched
	 */
	NetworkServiceDomain_PS      = 0x02,
	/**
	 * packet and circuit switched
	 */
	NetworkServiceDomain_CS_PS   = 0x03,
	NetworkServiceDomain_UNKNOWN = 0x04,
};

const char *FANCYQMI_API formatNetworkServiceDomain(NetworkServiceDomain nsd);

enum RoamingStatus{
    RoamingStatus_OFF                 = 0x00,
    RoamingStatus_ON                  = 0x01,
    /* Next ones only for 3GPP2 */
    RoamingStatus_BLINK               = 0x02,
    RoamingStatus_OUT_OF_NEIGHBORHOOD = 0x03,
    RoamingStatus_OUT_OF_BUILDING     = 0x04,
    RoamingStatus_PREFERRED_SYSTEM    = 0x05,
    RoamingStatus_AVAILABLE_SYSTEM    = 0x06,
    RoamingStatus_ALLIANCE_PARTNER    = 0x07,
    RoamingStatus_PREMIUM_PARTNER     = 0x08,
    RoamingStatus_FULL_SERVICE        = 0x09,
    RoamingStatus_PARTIAL_SERVICE     = 0x0A,
    RoamingStatus_BANNER_ON           = 0x0B,
    RoamingStatus_BANNER_OFF          = 0x0C
};

const char * FANCYQMI_API formatRoamingStatus(RoamingStatus rs);

enum WdsIpFamily {

	WdsIpFamilyUNSET       = 0,
	WdsIpFamilyIPv4        = 4,
	WdsIpFamilyIPv6        = 6,
	WdsIpFamilyUNSPECIFIED = 8
};

const char * FANCYQMI_API formatWdsIpFamily(WdsIpFamily ipFamily);

enum WdsTechnologyPreference{
	WdsTechnologyPreference_ALLOW_3GPP  = 1 << 0,
	WdsTechnologyPreference_ALLOW_3GPP2 = 1 << 1
};

std::string FANCYQMI_API formatWdsTechnologyPreferenceMask(int tpMask);

enum WdsExtendedTechnologyPreference {
    WdsExtendedTechnologyPreference_UNSET            = 0,
    WdsExtendedTechnologyPreference_CDMA             = 32769,
    WdsExtendedTechnologyPreference_UMTS             = 32772,
    WdsExtendedTechnologyPreference_EPC              = 34944,
    WdsExtendedTechnologyPreference_EMBMS            = 34946,
    WdsExtendedTechnologyPreference_MODEM_LINK_LOCAL = 34952,
};

const char * FANCYQMI_API formatWdsExtendedTechnologyPreference(WdsExtendedTechnologyPreference etp);

enum WdsCallType {
	WdsCallTypeLaptop   = 0,
	WdsCallTypeEmbedded = 1
};

std::string FANCYQMI_API formatWdsAuthenticationMask(int tpMask);

enum WdsAuthentication {
    WdsAuthentication_NONE = 0,
    WdsAuthentication_PAP  = 1 << 0,
    WdsAuthentication_CHAP = 1 << 1
};

const char * FANCYQMI_API formatWdsCallType(WdsCallType ct);

enum WdsCallEndReason {
    WdsCallEndReason_GENERIC_UNSPECIFIED                = 1,
    WdsCallEndReason_GENERIC_CLIENT_END                 = 2,
    WdsCallEndReason_GENERIC_NO_SERVICE                 = 3,
    WdsCallEndReason_GENERIC_FADE                       = 4,
    WdsCallEndReason_GENERIC_RELEASE_NORMAL             = 5,
    WdsCallEndReason_GENERIC_ACCESS_ATTEMPT_IN_PROGRESS = 6,
    WdsCallEndReason_GENERIC_ACCESS_FAILURE             = 7,
    WdsCallEndReason_GENERIC_REDIRECTION_OR_HANDOFF     = 8,
    WdsCallEndReason_GENERIC_CLOSE_IN_PROGRESS          = 9,
    WdsCallEndReason_GENERIC_AUTHENTICATION_FAILED      = 10,
    WdsCallEndReason_GENERIC_INTERNAL_ERROR             = 11,
    WdsCallEndReason_CDMA_LOCK                            = 500,
    WdsCallEndReason_CDMA_INTERCEPT                       = 501,
    WdsCallEndReason_CDMA_REORDER                         = 502,
    WdsCallEndReason_CDMA_RELEASE_SO_REJECT               = 503,
    WdsCallEndReason_CDMA_INCOMING_CALL                   = 504,
    WdsCallEndReason_CDMA_ALERT_STOP                      = 505,
    WdsCallEndReason_CDMA_ACTIVATION                      = 506,
    WdsCallEndReason_CDMA_MAX_ACCESS_PROBES               = 507,
    WdsCallEndReason_CDMA_CCS_NOT_SUPPORTED_BY_BS         = 508,
    WdsCallEndReason_CDMA_NO_RESPONSE_FROM_BS             = 509,
    WdsCallEndReason_CDMA_REJECTED_BY_BS                  = 510,
    WdsCallEndReason_CDMA_INCOMPATIBLE                    = 511,
    WdsCallEndReason_CDMA_ALREADY_IN_TC                   = 512,
    WdsCallEndReason_CDMA_USER_CALL_ORIGINATED_DURING_GPS = 513,
    WdsCallEndReason_CDMA_USER_CALL_ORIGINATED_DURING_SMS = 514,
    WdsCallEndReason_CDMA_NO_SERVICE                      = 515,
    WdsCallEndReason_GSM_WCDMA_CONFERENCE_FAILED                       = 1000,
    WdsCallEndReason_GSM_WCDMA_INCOMING_REJECTED                       = 1001,
    WdsCallEndReason_GSM_WCDMA_NO_SERVICE                              = 1002,
    WdsCallEndReason_GSM_WCDMA_NETWORK_END                             = 1003,
    WdsCallEndReason_GSM_WCDMA_LLC_SNDCP_FAILURE                       = 1004,
    WdsCallEndReason_GSM_WCDMA_INSUFFICIENT_RESOURCES                  = 1005,
    WdsCallEndReason_GSM_WCDMA_OPTION_TEMPORARILY_OUT_OF_ORDER         = 1006,
    WdsCallEndReason_GSM_WCDMA_NSAPI_ALREADY_USED                      = 1007,
    WdsCallEndReason_GSM_WCDMA_REGULAR_DEACTIVATION                    = 1008,
    WdsCallEndReason_GSM_WCDMA_NETWORK_FAILURE                         = 1009,
    WdsCallEndReason_GSM_WCDMA_REATTACH_REQUIRED                       = 1010,
    WdsCallEndReason_GSM_WCDMA_PROTOCOL_ERROR                          = 1011,
    WdsCallEndReason_GSM_WCDMA_OPERATOR_DETERMINED_BARRING             = 1012,
    WdsCallEndReason_GSM_WCDMA_UNKNOWN_APN                             = 1013,
    WdsCallEndReason_GSM_WCDMA_UNKNOWN_PDP                             = 1014,
    WdsCallEndReason_GSM_WCDMA_GGSN_REJECT                             = 1015,
    WdsCallEndReason_GSM_WCDMA_ACTIVATION_REJECT                       = 1016,
    WdsCallEndReason_GSM_WCDMA_OPTION_NOT_SUPPORTED                    = 1017,
    WdsCallEndReason_GSM_WCDMA_OPTION_UNSUBSCRIBED                     = 1018,
    WdsCallEndReason_GSM_WCDMA_QOS_NOT_ACCEPTED                        = 1019,
    WdsCallEndReason_GSM_WCDMA_TFT_SEMANTIC_ERROR                      = 1020,
    WdsCallEndReason_GSM_WCDMA_TFT_SYNTAX_ERROR                        = 1021,
    WdsCallEndReason_GSM_WCDMA_UNKNOWN_PDP_CONTEXT                     = 1022,
    WdsCallEndReason_GSM_WCDMA_FILTER_SEMANTIC_ERROR                   = 1023,
    WdsCallEndReason_GSM_WCDMA_FILTER_SYNTAX_ERROR                     = 1024,
    WdsCallEndReason_GSM_WCDMA_PDP_WITHOUT_ACTIVE_TFT                  = 1025,
    WdsCallEndReason_GSM_WCDMA_INVALID_TRANSACTION_ID                  = 1026,
    WdsCallEndReason_GSM_WCDMA_MESSAGE_INCORRECT_SEMANTIC              = 1027,
    WdsCallEndReason_GSM_WCDMA_INVALID_MANDATORY_INFO                  = 1028,
    WdsCallEndReason_GSM_WCDMA_MESSAGE_TYPE_UNSUPPORTED                = 1029,
    WdsCallEndReason_GSM_WCDMA_MESSAGE_TYPE_NONCOMPATIBLE_STATE        = 1030,
    WdsCallEndReason_GSM_WCDMA_UNKNOWN_INFO_ELEMENT                    = 1031,
    WdsCallEndReason_GSM_WCDMA_CONDITIONAL_IE_ERROR                    = 1032,
    WdsCallEndReason_GSM_WCDMA_MESSAGE_AND_PROTOCOL_STATE_UNCOMPATIBLE = 1033,
    WdsCallEndReason_GSM_WCDMA_APN_TYPE_CONFLICT                       = 1034,
    WdsCallEndReason_GSM_WCDMA_NO_GPRS_CONTEXT                         = 1035,
    WdsCallEndReason_GSM_WCDMA_FEATURE_NOT_SUPPORTED                   = 1036,
    WdsCallEndReason_EVDO_CONNECTION_DENY_GENERAL_OR_BUSY                   = 1500,
    WdsCallEndReason_EVDO_CONNECTION_DENY_BILLING_OR_AUTHENTICATION_FAILURE = 1501,
    WdsCallEndReason_EVDO_HDR_CHANGE                                        = 1502,
    WdsCallEndReason_EVDO_HDR_EXIT                                          = 1503,
    WdsCallEndReason_EVDO_HDR_NO_SESSION                                    = 1504,
    WdsCallEndReason_EVDO_HDR_ORIGINATION_DURING_GPS_FIX                    = 1505,
    WdsCallEndReason_EVDO_HDR_CONNECTION_SETUP_TIMEOUT                      = 1506,
    WdsCallEndReason_EVDO_HDR_RELEASED_BY_CM                                = 1507
};

const char * FANCYQMI_API formatWdsCallEndReason(WdsCallEndReason r);

enum WdsVerboseCallEndReasonType {
    WdsVerboseCallEndReasonType_MIP      = 1,
    WdsVerboseCallEndReasonType_INTERNAL = 2,
    WdsVerboseCallEndReasonType_CM       = 3,
    WdsVerboseCallEndReasonType_3GPP     = 6,
    WdsVerboseCallEndReasonType_PPP      = 7,
    WdsVerboseCallEndReasonType_EHRPD    = 8,
    WdsVerboseCallEndReasonType_IPV6     = 9
};

const char * FANCYQMI_API formatWdsVerboseCallEndReason(WdsVerboseCallEndReasonType rt, int reason);

enum WdsConnectionStatus {
    WdsConnectionStatusUnknown        = 0,
    WdsConnectionStatusDisconnected   = 1,
    WdsConnectionStatusConnected      = 2,
    WdsConnectionStatusSuspended      = 3,
    WdsConnectionStatusAuthenticating = 4

};

const char * FANCYQMI_API formatWdsConnectionStatus(WdsConnectionStatus cs);

}} // end namespaces

#endif
