/***********************************************************
 * $Id$
 *
 * FancyLibs qmi wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQMIPACKETSERVICESTATUS_H_
#define FANCYQMIPACKETSERVICESTATUS_H_

#include <fancyqmienums.h>
#include <fancynumbers.h>
#include <fancystring.h>

namespace Fancy {

class String;

namespace QMI {

/**
 * Output of WdsClient packet service status callback.
 */
class FANCYQMI_API QmiPacketServiceStatus : virtual public Fancy::Object
{
public:
	typedef Fancy::ObjPtr<QmiPacketServiceStatus> ptr_t;

	static ptr_t newInstance();

	std::string toString() const;

	WdsCallEndReason getCallEndReason() const {
		return this->callEndReason;
	}

	void setCallEndReason(WdsCallEndReason callEndReason) {
		this->callEndReason = callEndReason;
	}

	int getVerboseCallEndReason() const {
		return this->verboseCallEndReason;
	}

	void setVerboseCallEndReason(int verboseCallEndReason) {
		this->verboseCallEndReason = verboseCallEndReason;
	}

	WdsVerboseCallEndReasonType getVerboseCallEndReasonType() const {
		return this->verboseCallEndReasonType;
	}

	void setVerboseCallEndReasonType(
			WdsVerboseCallEndReasonType verboseCallEndReasonType) {
		this->verboseCallEndReasonType = verboseCallEndReasonType;
	}

	const char *getVerboseCallEndReasonString() const;

	WdsConnectionStatus getConnectionStatus() const {
		return this->connectionStatus;
	}

	void setConnectionStatus(WdsConnectionStatus connectionStatus) {
		this->connectionStatus = connectionStatus;
	}

	WdsExtendedTechnologyPreference getExtendedTechnologyPreference() const {
		return this->extendedTechnologyPreference;
	}

	void setExtendedTechnologyPreference(
			WdsExtendedTechnologyPreference extendedTechnologyPreference) {
		this->extendedTechnologyPreference = extendedTechnologyPreference;
	}

	WdsIpFamily getIpFamily() const {
		return this->ipFamily;
	}

	void setIpFamily(WdsIpFamily ipFamily) {
		this->ipFamily = ipFamily;
	}

	bool isReconfigurationReqired() const {
		return this->reconfigurationReqired;
	}

	void setReconfigurationReqired(bool reconfigurationReqired) {
		this->reconfigurationReqired = reconfigurationReqired;
	}

protected:

	WdsConnectionStatus connectionStatus;
	bool reconfigurationReqired;
	WdsIpFamily ipFamily;
	WdsExtendedTechnologyPreference extendedTechnologyPreference;
	WdsCallEndReason callEndReason;
	WdsVerboseCallEndReasonType verboseCallEndReasonType;
	int verboseCallEndReason;

	QmiPacketServiceStatus();
	virtual ~QmiPacketServiceStatus();

private:
};

}} // end namespaces

#endif
