/***********************************************************
 * $Id$
 *
 * FancyLibs qmi wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQMISIGNALINFO_H_
#define FANCYQMISIGNALINFO_H_

#include <fancyqmienums.h>
#include <fancyobject.h>

namespace Fancy {
namespace QMI {

/**
 * A detailed signal information reported to listeners.
 */
class FANCYQMI_API QmiSignalInfo : virtual public Fancy::Object
{
public:
	typedef Fancy::ObjPtr<QmiSignalInfo> ptr_t;

	static ptr_t newInstance();

	/**
	 * This is the rssi value, which is reported, when a certain
	 * radio interface reports no signal.
	 */
	static const int INVALID_RSSI = -256;

	int getCdmaEcio() const {
		return this->cdmaEcio;
	}

	void setCdmaEcio(int cdmaEcio) {
		this->cdmaEcio = cdmaEcio;
	}

	int getCdmaRssi() const {
		return this->cdmaRssi;
	}

	void setCdmaRssi(int cdmaRssi) {
		this->cdmaRssi = cdmaRssi;
	}

	int getGsmRssi() const {
		return this->gsmRssi;
	}

	void setGsmRssi(int gsmRssi) {
		this->gsmRssi = gsmRssi;
	}

	int getHdrEcio() const {
		return this->hdrEcio;
	}

	void setHdrEcIo(int hdrEcio) {
		this->hdrEcio = hdrEcio;
	}

	int getHdrIo() const {
		return this->hdrIo;
	}

	void setHdrIo(int hdrIo) {
		this->hdrIo = hdrIo;
	}

	int getHdrRssi() const {
		return this->hdrRssi;
	}

	void setHdrRssi(int hdrRssi) {
		this->hdrRssi = hdrRssi;
	}

	int getHdrSnr() const {
		return this->hdrSnr;
	}

	void setHdrSnr(int hdrSnr) {
		this->hdrSnr = hdrSnr;
	}

	int getLteRsrq() const {
		return this->lteRsrq;
	}

	void setLteRsrq(int lteRsrq) {
		this->lteRsrq = lteRsrq;
	}

	int getLteRsrp() const {
		return this->lteRsrp;
	}

	void setLteRsrp(int lteRsrp) {
		this->lteRsrp = lteRsrp;
	}

	int getLteRssi() const {
		return this->lteRssi;
	}

	void setLteRssi(int lteRssi) {
		this->lteRssi = lteRssi;
	}

	int getLteSnr() const {
		return this->lteSnr;
	}

	void setLteSnr(int lteSnr) {
		this->lteSnr = lteSnr;
	}

	int getWcdmaEcio() const {
		return this->wcdmaEcio;
	}

	void setWcdmaEcio(int wcdmaEcio) {
		this->wcdmaEcio = wcdmaEcio;
	}

	int getWcdmaRssi() const {
		return this->wcdmaRssi;
	}

	void setWcdmaRssi(int wcdmaRssi) {
		this->wcdmaRssi = wcdmaRssi;
	}

	/**
	 * @return the maximal valid rssi value and set the content
	 *         of radioInterface to the Radio interface, which
	 *         delivered the maximal value.
	 */
	int getMaxRssi(RadioInterface *radioInterface) const;

	std::string toString() const;

protected:

	QmiSignalInfo();
	virtual ~QmiSignalInfo();

private:

	int gsmRssi;

	int cdmaRssi;
	int cdmaEcio;

	int wcdmaRssi;
	int wcdmaEcio;

	int hdrRssi;
	int hdrEcio;
	int hdrIo;
	int hdrSnr;

	int lteRssi;
	int lteRsrq;
	int lteRsrp;
	int lteSnr;
};

}} // end namespaces

#endif
