/***********************************************************
 * $Id$
 *
 * FancyLibs qmi wrapper
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYQMISTARTNETWORKINPUT_H_
#define FANCYQMISTARTNETWORKINPUT_H_

#include <fancyqmienums.h>
#include <fancynumbers.h>
#include <fancystring.h>

namespace Fancy {

class String;

namespace QMI {

/**
 * Input for WdsClient->startNetwork()
 */
class FANCYQMI_API QmiStartNetworkInput : virtual public Fancy::Object
{
public:
	typedef Fancy::ObjPtr<QmiStartNetworkInput> ptr_t;

	static ptr_t newInstance();

	std::string toString() const;

	const Fancy::ObjPtr<Fancy::String>& getApn() const {
		return this->apn;
	}

	void setApn(const Fancy::ObjPtr<Fancy::String>& apn) {
		this->apn = apn;
	}

	int getAuthenticationPreference() const {
		return this->authenticationPreference;
	}

	void setAuthenticationPreference(int authenticationPreference) {
		this->authenticationPreference = authenticationPreference;
	}

	WdsCallType getCallType() const {
		return this->callType;
	}

	void setCallType(WdsCallType callType) {
		this->callType = callType;
	}

	const Fancy::ObjPtr<Fancy::Boolean> &getEnableAutoconnect() const {
		return this->enableAutoconnect;
	}

	void setEnableAutoconnect(const Fancy::ObjPtr<Fancy::Boolean> &enableAutoconnect) {
		this->enableAutoconnect = enableAutoconnect;
	}

	WdsExtendedTechnologyPreference getExtendedTechnologyPreference() const {
		return this->extendedTechnologyPreference;
	}

	void setExtendedTechnologyPreference(
			WdsExtendedTechnologyPreference extendedTechnologyPreference) {
		this->extendedTechnologyPreference = extendedTechnologyPreference;
	}

	WdsIpFamily getIpFamilyPreference() const {
		return this->ipFamilyPreference;
	}

	void setIpFamilyPreference(WdsIpFamily ipFamilyPreference) {
		this->ipFamilyPreference = ipFamilyPreference;
	}

	uint32_t getIpv4AddressPreference() const {
		return this->ipv4AddressPreference;
	}

	void setIpv4AddressPreference(uint32_t ipv4AddressPreference) {
		this->ipv4AddressPreference = ipv4AddressPreference;
	}

	const Fancy::ObjPtr<Fancy::String>& getPassword() const {
		return this->password;
	}

	void setPassword(const Fancy::ObjPtr<Fancy::String>& password) {
		this->password = password;
	}

	uint32_t getPrimaryDnsAddressPreference() const {
		return this->primaryDnsAddressPreference;
	}

	void setPrimaryDnsAddressPreference(uint32_t primaryDnsAddressPreference) {
		this->primaryDnsAddressPreference = primaryDnsAddressPreference;
	}

	uint32_t getPrimaryNbnsAddressPreference() const {
		return this->primaryNbnsAddressPreference;
	}

	void setPrimaryNbnsAddressPreference(
			uint32_t primaryNbnsAddressPreference) {
		this->primaryNbnsAddressPreference = primaryNbnsAddressPreference;
	}

	uint8_t getProfileIndex3gpp() const {
		return this->profileIndex3gpp;
	}

	void setProfileIndex3gpp(uint8_t profileIndex3gpp) {
		this->profileIndex3gpp = profileIndex3gpp;
	}

	uint8_t getProfileIndex3gpp2() const {
		return this->profileIndex3gpp2;
	}

	void setProfileIndex3gpp2(uint8_t profileIndex3gpp2) {
		this->profileIndex3gpp2 = profileIndex3gpp2;
	}

	uint32_t getSecondaryDnsAddressPreference() const {
		return this->secondaryDnsAddressPreference;
	}

	void setSecondaryDnsAddressPreference(
			uint32_t secondaryDnsAddressPreference) {
		this->secondaryDnsAddressPreference = secondaryDnsAddressPreference;
	}

	uint32_t getSecondaryNbnsAddressPreference() const {
		return this->secondaryNbnsAddressPreference;
	}

	void setSecondaryNbnsAddressPreference(
			uint32_t secondaryNbnsAddressPreference) {
		this->secondaryNbnsAddressPreference = secondaryNbnsAddressPreference;
	}

	int getTechnologyPreference() const {
		return this->technologyPreference;
	}

	void setTechnologyPreference(int technologyPreference) {
		this->technologyPreference = technologyPreference;
	}

	const Fancy::ObjPtr<Fancy::String>& getUsername() const {
		return this->username;
	}

	void setUsername(const Fancy::ObjPtr<Fancy::String>& username) {
		this->username = username;
	}

protected:

	Fancy::ObjPtr<Fancy::String> apn;
	int authenticationPreference;
	WdsCallType callType;
	Fancy::ObjPtr<Fancy::Boolean> enableAutoconnect;
	WdsExtendedTechnologyPreference extendedTechnologyPreference;
	WdsIpFamily ipFamilyPreference;
	uint32_t ipv4AddressPreference;
	Fancy::ObjPtr<Fancy::String> password;
	uint32_t primaryDnsAddressPreference;
	uint32_t primaryNbnsAddressPreference;
	uint8_t profileIndex3gpp;
	uint8_t profileIndex3gpp2;
	uint32_t secondaryDnsAddressPreference;
	uint32_t secondaryNbnsAddressPreference;
	int technologyPreference;
	Fancy::ObjPtr<Fancy::String> username;

	QmiStartNetworkInput();
	virtual ~QmiStartNetworkInput();

private:
};

}} // end namespaces

#endif
